#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

unlink tools
echo -e "\e[1;32mOMZ-tools Symbolic link Unlinked\e[0m"
